@@ -3,4 +3,4 @@ A color palette to make coloring consistent project wide.
 """
 from bokeh.colors import named
 
-lightcurve_colors = [named.mediumblue, named.firebrick, named.green, named.darkorange]
+light_curve_colors = [named.mediumblue, named.firebrick, named.green, named.darkorange]
