@@ -1,5 +1,5 @@
 """
-Code to lightcurves predicted by Ramjet in 2 minute data.
+Code to light curves predicted by Ramjet in 2 minute data.
 """
 import datetime
 import math
@@ -35,28 +35,28 @@ tess_toi_data_interface = TessToiDataInterface()
 
 
 class Target:
-    def __init__(self, lightcurve_path):
-        self.tic_id, self.sector = tess_data_interface.get_tic_id_and_sector_from_file_path(lightcurve_path)
+    def __init__(self, light_curve_path):
+        self.tic_id, self.sector = tess_data_interface.get_tic_id_and_sector_from_file_path(light_curve_path)
         self.pdcsap_fluxes: Union[np.ndarray, None] = None
         self.normalized_pdcsap_fluxes: Union[np.ndarray, None] = None
         self.pdcsap_flux_errors: Union[np.ndarray, None] = None
         self.normalized_pdcsap_flux_errors: Union[np.ndarray, None] = None
         self.sap_fluxes: Union[np.ndarray, None] = None
         self.normalized_sap_fluxes: Union[np.ndarray, None] = None
-        self.load_lightcurve()
+        self.load_light_curve()
         self.has_known_exofop_disposition = self.check_for_known_exofop_dispositions()
         tic_row = tess_data_interface.get_tess_input_catalog_row(self.tic_id)
         self.star_radius = tic_row['rad']
 
-    def load_lightcurve(self):
-        lightcurve_path = tess_data_interface.download_two_minute_cadence_lightcurve(self.tic_id, self.sector)
+    def load_light_curve(self):
+        light_curve_path = tess_data_interface.download_two_minute_cadence_light_curve(self.tic_id, self.sector)
         self.pdcsap_fluxes, self.pdcsap_flux_errors, self.times = tess_data_interface.load_fluxes_flux_errors_and_times_from_fits_file(
-            lightcurve_path, TessFluxType.PDCSAP, remove_nans=False)
+            light_curve_path, TessFluxType.PDCSAP, remove_nans=False)
         nonnegative_pdcsap_fluxes = self.pdcsap_fluxes - np.minimum(np.nanmin(self.pdcsap_fluxes), 0)
         pdcsap_flux_median = np.nanmedian(nonnegative_pdcsap_fluxes)
         self.normalized_pdcsap_fluxes = nonnegative_pdcsap_fluxes / pdcsap_flux_median - 1
         self.normalized_pdcsap_flux_errors = self.pdcsap_flux_errors / pdcsap_flux_median
-        self.sap_fluxes, _ = tess_data_interface.load_fluxes_and_times_from_fits_file(lightcurve_path,
+        self.sap_fluxes, _ = tess_data_interface.load_fluxes_and_times_from_fits_file(light_curve_path,
                                                                                       TessFluxType.SAP,
                                                                                       remove_nans=False)
         nonnegative_sap_fluxes = self.sap_fluxes - np.minimum(np.nanmin(self.sap_fluxes), 0)
@@ -82,15 +82,15 @@ class ResultsViewer:
         self.previous_button, self.next_button = self.create_target_switching_buttons()
         self.target_title_div = Div()
         self.target_title_div.sizing_mode = 'stretch_width'
-        self.lightcurve_figure, self.lightcurve_data_source = self.create_flux_comparison_lightcurve_figure()
+        self.light_curve_figure, self.light_curve_data_source = self.create_flux_comparison_light_curve_figure()
         self.known_planet_div = Div(text='This target has a known ExoFOP disposition',
                                     css_classes=['notification', 'is-warning', 'is-hidden', 'is-fullwidth'])
 
         self.fold_coordinate_data_source = ColumnDataSource({'Time (BTJD)': [], 'Normalized PDCSAP flux': []})
         self.event_coordinates = []
-        unfolded_lightcurve_figure = self.create_unfolded_lightcurve_figure(self.lightcurve_data_source)
-        folded_lightcurve_figure = self.create_folded_figured_based_on_clicks_in_unfolded_figure(unfolded_lightcurve_figure,
-                                                                                                 self.lightcurve_data_source)
+        unfolded_light_curve_figure = self.create_unfolded_light_curve_figure(self.light_curve_data_source)
+        folded_light_curve_figure = self.create_folded_figured_based_on_clicks_in_unfolded_figure(unfolded_light_curve_figure,
+                                                                                                  self.light_curve_data_source)
         self.star_radius = None
         self.depth = None
         self.period = None
@@ -111,22 +111,22 @@ class ResultsViewer:
         bokeh_document.add_root(self.next_button)
         self.target_title_div.name = 'target_title_div'
         bokeh_document.add_root(self.target_title_div)
-        self.lightcurve_figure.name = 'lightcurve_figure'
-        unfolded_lightcurve_figure.name = 'unfolded_lightcurve_figure'
-        folded_lightcurve_figure.name = 'folded_lightcurve_figure'
+        self.light_curve_figure.name = 'light_curve_figure'
+        unfolded_light_curve_figure.name = 'unfolded_light_curve_figure'
+        folded_light_curve_figure.name = 'folded_light_curve_figure'
         initial_fit_figure.name = 'initial_fit_figure'
         js_reset = CustomJS(code='''
-            Bokeh.documents[0].get_model_by_name("lightcurve_figure").reset.emit()
-            Bokeh.documents[0].get_model_by_name("unfolded_lightcurve_figure").reset.emit()
-            Bokeh.documents[0].get_model_by_name("folded_lightcurve_figure").reset.emit()
+            Bokeh.documents[0].get_model_by_name("light_curve_figure").reset.emit()
+            Bokeh.documents[0].get_model_by_name("unfolded_light_curve_figure").reset.emit()
+            Bokeh.documents[0].get_model_by_name("folded_light_curve_figure").reset.emit()
             Bokeh.documents[0].get_model_by_name("initial_fit_figure").reset.emit()
         ''')
-        self.lightcurve_data_source.js_on_change('data', js_reset)  # Hacky workaround until the Bokeh team makes a better solution. https://github.com/bokeh/bokeh/issues/9218
-        bokeh_document.add_root(self.lightcurve_figure)
+        self.light_curve_data_source.js_on_change('data', js_reset)  # Hacky workaround until the Bokeh team makes a better solution. https://github.com/bokeh/bokeh/issues/9218
+        bokeh_document.add_root(self.light_curve_figure)
         self.known_planet_div.name = 'known_planet_div'
         bokeh_document.add_root(self.known_planet_div)
-        bokeh_document.add_root(unfolded_lightcurve_figure)
-        bokeh_document.add_root(folded_lightcurve_figure)
+        bokeh_document.add_root(unfolded_light_curve_figure)
+        bokeh_document.add_root(folded_light_curve_figure)
         run_fitting_button.name = 'run_fitting_button'
         parameters_table.name = 'parameters_table'
         bokeh_document.add_root(run_fitting_button)
@@ -137,7 +137,7 @@ class ResultsViewer:
     @classmethod
     def attach_document(cls, bokeh_document, results_path, starting_index: int = 0):
         viewer = cls(bokeh_document, results_path, starting_index)
-        viewer.load_surrounding_lightcurves()
+        viewer.load_surrounding_light_curves()
         viewer.display_current_target()
         return viewer
 
@@ -207,10 +207,10 @@ class ResultsViewer:
         @gen.coroutine
         @without_document_lock
         def run_fitting():
-            times = self.lightcurve_data_source.data['Time (BTJD)'].astype(np.float32)
-            flux_errors = self.lightcurve_data_source.data['Normalized PDCSAP flux error']
-            fluxes = self.lightcurve_data_source.data['Normalized PDCSAP flux']
-            relative_times = self.lightcurve_data_source.data['Time (days)']
+            times = self.light_curve_data_source.data['Time (BTJD)'].astype(np.float32)
+            flux_errors = self.light_curve_data_source.data['Normalized PDCSAP flux error']
+            fluxes = self.light_curve_data_source.data['Normalized PDCSAP flux']
+            relative_times = self.light_curve_data_source.data['Time (days)']
             nan_indexes = np.union1d(np.argwhere(np.isnan(fluxes)), np.union1d(np.argwhere(np.isnan(times)),
                                                                                np.argwhere(np.isnan(flux_errors))))
             fluxes = np.delete(fluxes, nan_indexes)
@@ -287,8 +287,9 @@ class ResultsViewer:
             self.bokeh_document.add_next_tick_callback(partial(fit, self, map_soln, model))
 
         run_fitting_button.on_click(run_fitting)
-        self.plot_folding_colored_lightcurve_source(initial_fit_figure, self.initial_fit_data_source,
-                                                    time_column_name='Folded time (days)', flux_column_name='Relative flux')
+        self.plot_folding_colored_light_curve_source(initial_fit_figure, self.initial_fit_data_source,
+                                                     time_column_name='Folded time (days)',
+                                                     flux_column_name='Relative flux')
         initial_fit_figure.line('Fit time', 'Fit', source=self.initial_fit_data_source, color='black', line_width=3)
         initial_fit_figure.sizing_mode = 'stretch_width'
 
@@ -305,8 +306,8 @@ class ResultsViewer:
                                color='red', alpha=0.8)  # Will be updated.
         # Prepare the folded plot.
         folded_figure = Figure(x_axis_label='Folded time (days)', y_axis_label='Normalized PDCSAP flux',
-                               title=f'Folded lightcurve')
-        self.plot_folding_colored_lightcurve_source(folded_figure, data_source, time_column_name='Folded time (days)')
+                               title=f'Folded light curve')
+        self.plot_folding_colored_light_curve_source(folded_figure, data_source, time_column_name='Folded time (days)')
         folded_figure.sizing_mode = 'stretch_width'
         self_ = self
 
@@ -398,14 +399,14 @@ class ResultsViewer:
         period = np.average(period_estimates, weights=cycles_per_time_difference)
         return epoch, period
 
-    def create_unfolded_lightcurve_figure(self, data_source):
-        figure = Figure(title='Unfolded lightcurve', x_axis_label='Time (BTJD)', y_axis_label='Normalized PDCSAP flux',
+    def create_unfolded_light_curve_figure(self, data_source):
+        figure = Figure(title='Unfolded light curve', x_axis_label='Time (BTJD)', y_axis_label='Normalized PDCSAP flux',
                         active_drag='box_zoom')
-        self.plot_folding_colored_lightcurve_source(figure, data_source)
+        self.plot_folding_colored_light_curve_source(figure, data_source)
         figure.sizing_mode = 'stretch_width'
         return figure
 
-    def load_surrounding_lightcurves(self):
+    def load_surrounding_light_curves(self):
         load_range_start = self.current_target_index - self.number_of_indexes_before_and_after_to_load
         previous_indexes_to_load = [index for index in range(load_range_start, self.current_target_index)
                                     if 0 <= index < self.results_data_frame.shape[0]]
@@ -418,8 +419,8 @@ class ResultsViewer:
                              if 0 <= index < self.results_data_frame.shape[0]]
         for index_to_load in indexes_to_load:
             if index_to_load not in self.target_future_dictionary:
-                lightcurve_path = self.results_data_frame['Lightcurve path'].iloc[index_to_load]
-                target_pool_apply_result = self.pool_executor.submit(self.target_type, lightcurve_path)
+                light_curve_path = self.results_data_frame['light_curve_path'].iloc[index_to_load]
+                target_pool_apply_result = self.pool_executor.submit(self.target_type, light_curve_path)
                 self.target_future_dictionary[index_to_load] = target_pool_apply_result
         for index_to_delete in indexes_to_delete:
             if index_to_delete in self.target_future_dictionary:
@@ -435,7 +436,7 @@ class ResultsViewer:
             self.known_planet_div.css_classes = list(set(self.known_planet_div.css_classes) - {'is-hidden'})
         else:
             self.known_planet_div.css_classes = list(set(self.known_planet_div.css_classes).union({'is-hidden'}))
-        self.lightcurve_data_source.data = {'Time (BTJD)': target.times,
+        self.light_curve_data_source.data = {'Time (BTJD)': target.times,
                                             'Normalized PDCSAP flux': target.normalized_pdcsap_fluxes,
                                             'Normalized PDCSAP flux error': target.normalized_pdcsap_flux_errors,
                                             'Normalized SAP flux': target.normalized_sap_fluxes,
@@ -450,33 +451,33 @@ class ResultsViewer:
 
 
     @staticmethod
-    def create_flux_comparison_lightcurve_figure() -> (Figure, ColumnDataSource):
+    def create_flux_comparison_light_curve_figure() -> (Figure, ColumnDataSource):
         figure = Figure(title='Normalized flux comparison', x_axis_label='Time (BTJD)', y_axis_label='Normalized flux',
                         active_drag='box_zoom')
         data_source = ColumnDataSource({'Time (BTJD)': [], 'Normalized PDCSAP flux': [], 'Normalized SAP flux': [],
                                         'Time (days)': [], 'Folded time (days)': []})
 
-        def add_lightcurve(times_column_name, fluxes_column_name, legend_label, color):
-            """Adds a lightcurve to the figure."""
+        def add_light_curve(times_column_name, fluxes_column_name, legend_label, color):
+            """Adds a light curve to the figure."""
             figure.line(source=data_source, x=times_column_name, y=fluxes_column_name, line_color=color, line_alpha=0.1)
             figure.circle(source=data_source, x=times_column_name, y=fluxes_column_name, legend_label=legend_label,
                           line_color=color, line_alpha=0.4, fill_color=color, fill_alpha=0.1)
 
-        add_lightcurve('Time (BTJD)', 'Normalized PDCSAP flux', 'PDCSAP', 'firebrick')
-        add_lightcurve('Time (BTJD)', 'Normalized SAP flux', 'SAP', 'mediumblue')
+        add_light_curve('Time (BTJD)', 'Normalized PDCSAP flux', 'PDCSAP', 'firebrick')
+        add_light_curve('Time (BTJD)', 'Normalized SAP flux', 'SAP', 'mediumblue')
         figure.sizing_mode = 'stretch_width'
         return figure, data_source
 
     @staticmethod
-    def plot_folding_colored_lightcurve_source(figure: Figure, data_source: ColumnDataSource,
+    def plot_folding_colored_light_curve_source(figure: Figure, data_source: ColumnDataSource,
                                                time_column_name: str = 'Time (BTJD)',
                                                flux_column_name: str = 'Normalized PDCSAP flux',
                                                color_value_column_name: str = 'Time (days)'):
         """
-        Plots the lightcurve data source on the passed figure.
+        Plots the light curve data source on the passed figure.
 
         :param figure: The figure to plot to.
-        :param data_source: The data source containing the lightcurve data.
+        :param data_source: The data source containing the light curve data.
         :param time_column_name: The name of the time column whose values will be used on the x axis.
         :param flux_column_name: The name of the flux column whose values will be used on the y axis.
         :param color_value_column_name: The name of the column whose values will be used to determine data point color.
@@ -489,11 +490,11 @@ class ResultsViewer:
     def create_target_switching_buttons(self):
         def display_next_target():
             self.current_target_index += 1
-            self.load_surrounding_lightcurves()
+            self.load_surrounding_light_curves()
             self.display_current_target()
         def display_previous_target():
             self.current_target_index -= 1
-            self.load_surrounding_lightcurves()
+            self.load_surrounding_light_curves()
             self.display_current_target()
         next_button = Button(label='Next target')
         next_button.on_click(display_next_target)
@@ -507,8 +508,8 @@ class ResultsViewer:
         add_to_negatives_button = Button(label='Add to negatives')
         negatives_csv_file_path = Path('negatives.csv')
         def add_to_negatives():
-            lightcurve_path = self.results_data_frame['Lightcurve path'].iloc[self.current_target_index]
-            negative_data_frame = pd.DataFrame({'Lightcurve path': [lightcurve_path]})
+            light_curve_path = self.results_data_frame['light_curve_path'].iloc[self.current_target_index]
+            negative_data_frame = pd.DataFrame({'light_curve_path': [light_curve_path]})
             if negatives_csv_file_path.exists():
                 negative_data_frame.to_csv(negatives_csv_file_path, mode='a', header=False)
             else:
