@@ -1,6 +1,14 @@
 """
 Code for a class for common interfacing with TESS data, such as downloading, sorting, and manipulating.
 """
+import astroquery
+import lightkurve
+
+try:
+    from enum import StrEnum
+except ImportError:
+    from backports.strenum import StrEnum
+
 import math
 import re
 import shutil
@@ -22,7 +30,7 @@ from bokeh.io import show
 from retrying import retry
 from bokeh.plotting import Figure
 
-from ramjet.analysis.lightcurve_visualizer import plot_lightcurve, create_dual_lightcurve_figure
+from ramjet.analysis.light_curve_visualizer import plot_light_curve, create_dual_light_curve_figure
 
 
 class TessFluxType(Enum):
@@ -33,6 +41,14 @@ class TessFluxType(Enum):
     PDCSAP = 'PDCSAP_FLUX'
 
 
+class ColumnName(StrEnum):
+    """
+    An enum for the names of the columns produced by the data interface class.
+    """
+    TIC_ID = 'TIC ID'
+    SECTOR = 'Sector'
+
+
 def is_common_mast_connection_error(exception: Exception) -> bool:
     """
     Returns if the passed exception is a common MAST connection error. Made for deciding whether to retry a function.
@@ -40,9 +56,17 @@ def is_common_mast_connection_error(exception: Exception) -> bool:
     :param exception: The exception to check.
     :return: A boolean stating if the exception is a common MAST connection error.
     """
+    print(f'Retrying on {exception}...', flush=True)
+    # TODO: Rename function, as it includes more than just MAST now.
     return (isinstance(exception, AstroQueryTimeoutError) or
+            isinstance(exception, TimeoutError) or
             isinstance(exception, requests.exceptions.ReadTimeout) or
-            isinstance(exception, requests.exceptions.ConnectionError))
+            isinstance(exception, requests.exceptions.ChunkedEncodingError) or
+            isinstance(exception, requests.exceptions.HTTPError) or
+            isinstance(exception, requests.exceptions.ConnectionError) or
+            isinstance(exception, ConnectionResetError) or
+            isinstance(exception, lightkurve.search.SearchError) or
+            isinstance(exception, astroquery.exceptions.RemoteServiceError))
 
 
 class NoDataProductsFoundException(Exception):
@@ -89,7 +113,7 @@ class TessDataInterface:
         return observations
 
     @staticmethod
-    @retry(retry_on_exception=is_common_mast_connection_error)
+    @retry(retry_on_exception=is_common_mast_connection_error, stop_max_attempt_number=10)
     def get_all_tess_time_series_observations_chunk(tic_id: Union[int, List[int]] = None) -> pd.DataFrame:
         """
         Gets all TESS time-series observations, limited to science data product level. Repeats download attempt on
@@ -127,7 +151,7 @@ class TessDataInterface:
         return product_list
 
     @staticmethod
-    @retry(retry_on_exception=is_common_mast_connection_error)
+    @retry(retry_on_exception=is_common_mast_connection_error, stop_max_attempt_number=10)
     def get_product_list_chunk(observations: pd.DataFrame) -> pd.DataFrame:
         """
         A wrapper for MAST's `get_product_list`, allowing the use of Pandas DataFrames instead of AstroPy Tables.
@@ -140,7 +164,7 @@ class TessDataInterface:
         return data_products.to_pandas()
 
     @staticmethod
-    @retry(retry_on_exception=is_common_mast_connection_error)
+    @retry(retry_on_exception=is_common_mast_connection_error, stop_max_attempt_number=10)
     def download_products(data_products: pd.DataFrame, data_directory: Path) -> pd.DataFrame:
         """
          A wrapper for MAST's `download_products`, allowing the use of Pandas DataFrames instead of AstroPy Tables.
@@ -222,7 +246,7 @@ class TessDataInterface:
         :param data_frame: The data frame of single-sector entries.
         :return: The table with the added TIC ID column.
         """
-        data_frame['TIC ID'] = data_frame['obs_id'].map(self.get_tic_id_from_single_sector_obs_id)
+        data_frame[ColumnName.TIC_ID] = data_frame['obs_id'].map(self.get_tic_id_from_single_sector_obs_id)
         return data_frame
 
     def add_sector_column_to_single_sector_observations(self, observations: pd.DataFrame) -> pd.DataFrame:
@@ -232,42 +256,43 @@ class TessDataInterface:
         :param observations: The table of single-sector observations.
         :return: The table with the added sector column.
         """
-        observations['Sector'] = observations['obs_id'].map(self.get_sector_from_single_sector_obs_id)
+        observations[ColumnName.SECTOR] = observations['obs_id'].map(self.get_sector_from_single_sector_obs_id)
         return observations
 
-    def load_lightcurve_from_fits_file(self, lightcurve_path: Union[str, Path]) -> Dict[str, np.ndarray]:
+    def load_light_curve_from_fits_file(self, light_curve_path: Union[str, Path]) -> Dict[str, np.ndarray]:
         """
-        Loads a lightcurve from a FITS file in a dictionary form with the structure of the FITS arrays.
+        Loads a light_curve from a FITS file in a dictionary form with the structure of the FITS arrays.
 
-        :param lightcurve_path: The path to the FITS file.
-        :return: The lightcurve.
+        :param light_curve_path: The path to the FITS file.
+        :return: The light_curve.
         """
         try:
-            with fits.open(lightcurve_path) as hdu_list:
-                lightcurve = hdu_list[1].data  # Lightcurve information is in first extension table.
+            with fits.open(light_curve_path) as hdu_list:
+                light_curve = hdu_list[1].data  # Light curve information is in first extension table.
         except OSError:  # If the FITS file is corrupt, re-download (seems to happen often enough).
-            lightcurve_path = Path(lightcurve_path)  # In case it's currently a string.
-            lightcurve_path.unlink()
-            tic_id, sector = self.get_tic_id_and_sector_from_file_path(lightcurve_path)
-            self.download_two_minute_cadence_lightcurve(tic_id=tic_id, sector=sector, save_directory=lightcurve_path.parent)
-            with fits.open(lightcurve_path) as hdu_list:
-                lightcurve = hdu_list[1].data  # Lightcurve information is in first extension table.
-        return lightcurve
+            light_curve_path = Path(light_curve_path)  # In case it's currently a string.
+            light_curve_path.unlink()
+            tic_id, sector = self.get_tic_id_and_sector_from_file_path(light_curve_path)
+            self.download_two_minute_cadence_light_curve(tic_id=tic_id, sector=sector,
+                                                         save_directory=light_curve_path.parent)
+            with fits.open(light_curve_path) as hdu_list:
+                light_curve = hdu_list[1].data  # Light curve information is in first extension table.
+        return light_curve
 
-    def load_fluxes_and_times_from_fits_file(self, lightcurve_path: Union[str, Path],
+    def load_fluxes_and_times_from_fits_file(self, light_curve_path: Union[str, Path],
                                              flux_type: TessFluxType = TessFluxType.PDCSAP,
                                              remove_nans: bool = True) -> (np.ndarray, np.ndarray):
         """
         Extract the flux and time values from a TESS FITS file.
 
-        :param lightcurve_path: The path to the FITS file.
+        :param light_curve_path: The path to the FITS file.
         :param flux_type: The flux type to extract from the FITS file.
         :param remove_nans: Whether or not to remove nans.
         :return: The flux and times values from the FITS file.
         """
-        lightcurve = self.load_lightcurve_from_fits_file(lightcurve_path)
-        fluxes = lightcurve[flux_type.value]
-        times = lightcurve['TIME']
+        light_curve = self.load_light_curve_from_fits_file(light_curve_path)
+        fluxes = light_curve[flux_type.value]
+        times = light_curve['TIME']
         assert times.shape == fluxes.shape
         if remove_nans:
             # noinspection PyUnresolvedReferences
@@ -276,22 +301,22 @@ class TessDataInterface:
             times = np.delete(times, nan_indexes)
         return fluxes, times
 
-    def load_fluxes_flux_errors_and_times_from_fits_file(self, lightcurve_path: Union[str, Path],
+    def load_fluxes_flux_errors_and_times_from_fits_file(self, light_curve_path: Union[str, Path],
                                                          flux_type: TessFluxType = TessFluxType.PDCSAP,
                                                          remove_nans: bool = True
                                                          ) -> (np.ndarray, np.ndarray, np.ndarray):
         """
         Extract the flux and time values from a TESS FITS file.
 
-        :param lightcurve_path: The path to the FITS file.
+        :param light_curve_path: The path to the FITS file.
         :param flux_type: The flux type to extract from the FITS file.
         :param remove_nans: Whether or not to remove nans.
         :return: The flux and times values from the FITS file.
         """
-        lightcurve = self.load_lightcurve_from_fits_file(lightcurve_path)
-        fluxes = lightcurve[flux_type.value]
-        flux_errors = lightcurve[flux_type.value + '_ERR']
-        times = lightcurve['TIME']
+        light_curve = self.load_light_curve_from_fits_file(light_curve_path)
+        fluxes = light_curve[flux_type.value]
+        flux_errors = light_curve[flux_type.value + '_ERR']
+        times = light_curve['TIME']
         assert times.shape == fluxes.shape
         if remove_nans:
             # noinspection PyUnresolvedReferences
@@ -302,12 +327,12 @@ class TessDataInterface:
             times = np.delete(times, nan_indexes)
         return fluxes, flux_errors, times
 
-    def download_two_minute_cadence_lightcurve(self, tic_id: int, sector: int = None,
+    def download_two_minute_cadence_light_curve(self, tic_id: int, sector: int = None,
                                                save_directory: Union[Path, str] = None) -> Path:
         """
-        Downloads a lightcurve from MAST.
+        Downloads a light curve from MAST.
 
-        :param tic_id: The TIC ID of the lightcurve target to download.
+        :param tic_id: The TIC ID of the light curve target to download.
         :param sector: The sector to download. If not specified, downloads first available sector.
         :param save_directory: The directory to save the FITS file to. If not specified, uses the system temporary
                                directory.
@@ -318,81 +343,82 @@ class TessDataInterface:
         two_minute_observations = self.filter_out_twenty_second_cadence_observations(single_sector_observations)
         observations_with_sectors = self.add_sector_column_to_single_sector_observations(two_minute_observations)
         if sector is not None:
-            observations_with_sectors = observations_with_sectors[observations_with_sectors['Sector'] == sector]
+            observations_with_sectors = observations_with_sectors[
+                observations_with_sectors[ColumnName.SECTOR] == sector]
         else:
             observations_with_sectors = observations_with_sectors.head(1)
         product_list = self.get_product_list(observations_with_sectors)
-        lightcurves_product_list = product_list[product_list['productSubGroupDescription'] == 'LC']
-        manifest = self.download_products(lightcurves_product_list, data_directory=Path(tempfile.gettempdir()))
-        lightcurve_path = Path(manifest['Local Path'].iloc[0])
+        light_curves_product_list = product_list[product_list['productSubGroupDescription'] == 'LC']
+        manifest = self.download_products(light_curves_product_list, data_directory=Path(tempfile.gettempdir()))
+        light_curve_path = Path(manifest['Local Path'].iloc[0])
         if save_directory is not None:
             save_directory = Path(save_directory)
             save_directory.mkdir(parents=True, exist_ok=True)
-            new_lightcurve_path = str(save_directory.joinpath(lightcurve_path.name))
-            shutil.move(str(lightcurve_path), new_lightcurve_path)
-            lightcurve_path = new_lightcurve_path
-        return lightcurve_path
+            new_light_curve_path = save_directory.joinpath(light_curve_path.name)
+            shutil.move(str(light_curve_path), str(new_light_curve_path))
+            light_curve_path = new_light_curve_path
+        return light_curve_path
 
-    def plot_lightcurve_from_mast(self, tic_id: int, sector: int = None, exclude_flux_outliers: bool = False,
+    def plot_light_curve_from_mast(self, tic_id: int, sector: int = None, exclude_flux_outliers: bool = False,
                                   base_data_point_size=3):
         """
-        Downloads and plots a lightcurve from MAST.
+        Downloads and plots a light curve from MAST.
 
-        :param tic_id: The TIC ID of the lightcurve target to download.
+        :param tic_id: The TIC ID of the light curve target to download.
         :param sector: The sector to download. If not specified, downloads first available sector.
         :param exclude_flux_outliers: Whether or not to exclude flux outlier data points when plotting.
         :param base_data_point_size: The size of the data points to use when plotting (and related sizes).
         """
-        lightcurve_path = self.download_two_minute_cadence_lightcurve(tic_id, sector)
-        fluxes, times = self.load_fluxes_and_times_from_fits_file(lightcurve_path)
+        light_curve_path = self.download_two_minute_cadence_light_curve(tic_id, sector)
+        fluxes, times = self.load_fluxes_and_times_from_fits_file(light_curve_path)
         if sector is None:
-            sector = self.get_sector_from_single_sector_obs_id(str(lightcurve_path.stem))
+            sector = self.get_sector_from_single_sector_obs_id(str(light_curve_path.stem))
         title = f'TIC {tic_id} sector {sector}'
         if exclude_flux_outliers:
             title += ' (outliers removed)'
-        plot_lightcurve(times=times, fluxes=fluxes, exclude_flux_outliers=exclude_flux_outliers, title=title,
-                        base_data_point_size=base_data_point_size)
+        plot_light_curve(times=times, fluxes=fluxes, title=title, exclude_flux_outliers=exclude_flux_outliers,
+                         base_data_point_size=base_data_point_size)
 
     def create_pdcsap_and_sap_comparison_figure_from_mast(self, tic_id: int, sector: int = None) -> Figure:
         """
         Creates a comparison figure containing both the PDCSAP and SAP signals.
 
-        :param tic_id: The TIC ID of the lightcurve to plot.
-        :param sector: The sector of the lightcurve to plot.
+        :param tic_id: The TIC ID of the light curve to plot.
+        :param sector: The sector of the light curve to plot.
         :return: The generated figure.
         """
-        lightcurve_path = self.download_two_minute_cadence_lightcurve(tic_id, sector)
-        pdcsap_fluxes, pdcsap_times = self.load_fluxes_and_times_from_fits_file(lightcurve_path, TessFluxType.PDCSAP)
+        light_curve_path = self.download_two_minute_cadence_light_curve(tic_id, sector)
+        pdcsap_fluxes, pdcsap_times = self.load_fluxes_and_times_from_fits_file(light_curve_path, TessFluxType.PDCSAP)
         normalized_pdcsap_fluxes = pdcsap_fluxes / np.median(pdcsap_fluxes)
-        sap_fluxes, sap_times = self.load_fluxes_and_times_from_fits_file(lightcurve_path, TessFluxType.SAP)
+        sap_fluxes, sap_times = self.load_fluxes_and_times_from_fits_file(light_curve_path, TessFluxType.SAP)
         normalized_sap_fluxes = sap_fluxes / np.median(sap_fluxes)
         if sector is None:
-            _, sector = self.get_tic_id_and_sector_from_file_path(lightcurve_path)
+            _, sector = self.get_tic_id_and_sector_from_file_path(light_curve_path)
         title = f'TIC {tic_id} sector {sector}'
-        figure = create_dual_lightcurve_figure(fluxes0=normalized_pdcsap_fluxes, times0=pdcsap_times, name0='PDCSAP',
-                                               fluxes1=normalized_sap_fluxes, times1=sap_times, name1='SAP',
-                                               title=title, x_axis_label='Time (BTJD)')
+        figure = create_dual_light_curve_figure(fluxes0=normalized_pdcsap_fluxes, times0=pdcsap_times, name0='PDCSAP',
+                                                fluxes1=normalized_sap_fluxes, times1=sap_times, name1='SAP',
+                                                title=title, x_axis_label='Time (BTJD)')
         return figure
 
     def show_pdcsap_and_sap_comparison_from_mast(self, tic_id: int, sector: int = None):
         """
         Shows a comparison figure containing both the PDCSAP and SAP signals.
 
-        :param tic_id: The TIC ID of the lightcurve to plot.
-        :param sector: The sector of the lightcurve to plot.
+        :param tic_id: The TIC ID of the light curve to plot.
+        :param sector: The sector of the light curve to plot.
         """
         comparison_figure = self.create_pdcsap_and_sap_comparison_figure_from_mast(tic_id, sector)
         comparison_figure.sizing_mode = 'stretch_width'
         show(comparison_figure)
 
-    def show_lightcurve(self, lightcurve_path: Path):
+    def show_light_curve(self, light_curve_path: Path):
         """
-        Shows a figure of the lightcurve at the passed path.
+        Shows a figure of the light curve at the passed path.
 
-        :param lightcurve_path: The path of the lightcurve.
+        :param light_curve_path: The path of the light curve.
         """
-        fluxes, times = self.load_fluxes_and_times_from_fits_file(lightcurve_path)
-        figure = Figure(title=str(lightcurve_path), x_axis_label='Flux', y_axis_label='Time', active_drag='box_zoom')
+        fluxes, times = self.load_fluxes_and_times_from_fits_file(light_curve_path)
+        figure = Figure(title=str(light_curve_path), x_axis_label='Flux', y_axis_label='Time', active_drag='box_zoom')
         color = 'mediumblue'
         figure.line(times, fluxes, line_color=color, line_alpha=0.1)
         figure.circle(times, fluxes, line_color=color, line_alpha=0.4, fill_color=color, fill_alpha=0.1)
@@ -413,6 +439,7 @@ class TessDataInterface:
         return SkyCoord(ra, dec, unit='deg')
 
     @staticmethod
+    @retry(retry_on_exception=is_common_mast_connection_error, stop_max_attempt_number=10)
     def get_tess_input_catalog_row(tic_id: int) -> pd.Series:
         """
         Get the TIC row for a TIC ID.
@@ -467,25 +494,25 @@ class TessDataInterface:
         print_data_frame.reset_index(drop=True, inplace=True)
         print(print_data_frame)
 
-    def download_two_minute_cadence_lightcurves(self, save_directory: Path, limit: Union[None, int] = None):
+    def download_two_minute_cadence_light_curves(self, save_directory: Path, limit: Union[None, int] = None):
         """
-        Downloads all two minute cadence lightcurves from TESS.
+        Downloads all two minute cadence light curves from TESS.
 
-        :param save_directory: The directory to save the lightcurves to.
-        :param limit: Limits the number of lightcurves downloaded. Default of None will download all lightcurves.
+        :param save_directory: The directory to save the light curves to.
+        :param limit: Limits the number of light curves downloaded. Default of None will download all light curves.
         """
-        print(f'Starting download of 2-minute cadence lightcurves to directory `{save_directory}`.')
+        print(f'Starting download of 2-minute cadence light curves to directory `{save_directory}`.')
         save_directory.mkdir(parents=True, exist_ok=True)
         print(f'Retrieving observations list from MAST...')
         single_sector_observations = self.get_all_two_minute_single_sector_observations()
         print(f'Retrieving data products list from MAST...')
         data_products = self.get_product_list(single_sector_observations)
-        print(f'Downloading lightcurves...')
-        lightcurve_data_products = data_products[data_products['productFilename'].str.endswith('lc.fits')]
+        print(f'Downloading light curves...')
+        light_curve_data_products = data_products[data_products['productFilename'].str.endswith('lc.fits')]
         if limit is not None:
-            lightcurve_data_products = lightcurve_data_products.sample(frac=1, random_state=0).head(limit)
-        download_manifest = self.download_products(lightcurve_data_products, data_directory=save_directory)
-        print(f'Moving lightcurves to {save_directory}...')
+            light_curve_data_products = light_curve_data_products.sample(frac=1, random_state=0).head(limit)
+        download_manifest = self.download_products(light_curve_data_products, data_directory=save_directory)
+        print(f'Moving light curves to {save_directory}...')
         for _, manifest_row in download_manifest.iterrows():
             if manifest_row['Status'] == 'COMPLETE':
                 file_path = Path(manifest_row['Local Path'])
@@ -503,7 +530,7 @@ class TessDataInterface:
         single_sector_observations = self.filter_for_single_sector_observations(time_series_observations)
         two_minute_observations = self.filter_out_twenty_second_cadence_observations(single_sector_observations)
         single_sector_observations = self.add_sector_column_to_single_sector_observations(two_minute_observations)
-        return sorted(single_sector_observations['Sector'].unique())
+        return sorted(single_sector_observations[ColumnName.SECTOR].unique())
 
     def get_all_two_minute_single_sector_observations(self, tic_ids: List[int] = None) -> pd.DataFrame:
         """
@@ -521,21 +548,21 @@ class TessDataInterface:
             two_minute_observations)
         return two_minute_observations
 
-    def verify_lightcurve(self, lightcurve_path: Path):
+    def verify_light_curve(self, light_curve_path: Path):
         """
-        The lightcurve is checked if it's malformed, and if it is, it is re-downloaded.
+        The light_curve is checked if it's malformed, and if it is, it is re-downloaded.
 
-        :param lightcurve_path: The path of the lightcurve.
+        :param light_curve_path: The path of the light_curve.
         """
         try:
-            hdu_list = fits.open(str(lightcurve_path))
-            lightcurve = hdu_list[1].data
-            _ = lightcurve['TIME'][0]  # Basic check if the lightcurve file is malformed.
+            hdu_list = fits.open(str(light_curve_path))
+            light_curve = hdu_list[1].data
+            _ = light_curve['TIME'][0]  # Basic check if the light_curve file is malformed.
         except (OSError, TypeError):
-            print(f'{lightcurve_path} seems to be malformed. Re-downloading and replacing.')
-            sector = self.get_sector_from_single_sector_obs_id(str(lightcurve_path.stem))
-            tic_id = self.get_tic_id_from_single_sector_obs_id(str(lightcurve_path.stem))
-            self.download_two_minute_cadence_lightcurve(tic_id, sector, save_directory=lightcurve_path.parent)
+            print(f'{light_curve_path} seems to be malformed. Re-downloading and replacing.')
+            sector = self.get_sector_from_single_sector_obs_id(str(light_curve_path.stem))
+            tic_id = self.get_tic_id_from_single_sector_obs_id(str(light_curve_path.stem))
+            self.download_two_minute_cadence_light_curve(tic_id, sector, save_directory=light_curve_path.parent)
 
     @staticmethod
     def get_tic_id_and_sector_from_file_path(file_path: Union[Path, str]):
@@ -566,5 +593,5 @@ if __name__ == '__main__':
         limit_ = int(sys.argv[1])
     else:
         limit_ = None
-    tess_data_interface.download_two_minute_cadence_lightcurves(Path('data/tess_two_minute_cadence_lightcurves'),
-                                                                limit=limit_)
+    tess_data_interface.download_two_minute_cadence_light_curves(Path('data/tess_two_minute_cadence_light_curves'),
+                                                                 limit=limit_)
