@@ -13,11 +13,11 @@ def download():
     Downloads and prepares the data needed for the quick start tutorial.
     """
     tess_data_interface = TessDataInterface()
-    tess_data_interface.download_two_minute_cadence_lightcurves(
-        Path('data/tess_two_minute_cadence_lightcurves'), limit=10000)
+    tess_data_interface.download_two_minute_cadence_light_curves(Path('data/tess_two_minute_cadence_light_curves'),
+                                                                 limit=10000)
     tess_toi_data_interface = TessToiDataInterface()
-    tess_toi_data_interface.download_exofop_toi_lightcurves_to_directory(
-        Path('data/tess_two_minute_cadence_lightcurves'))
+    tess_toi_data_interface.download_exofop_toi_light_curves_to_directory(
+        Path('data/tess_two_minute_cadence_light_curves'))
     build_tables()
 
 
